#
# spec file for package vimb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vimb
Version:        3.7.0
Release:        1.5
Summary:        The vim-like browser
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            https://fanglingsu.github.io/vimb/
Source:         https://github.com/fanglingsu/vimb/archive/%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  appstream-glib
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(webkit2gtk-4.1)

%description
vimb is a WebKit-based web browser that behaves like the vimperator
plugin for Firefox, and has usage paradigms from the editor vim.

%prep
%autosetup -p1

%build
%make_build PREFIX=%{_prefix}

%install
%make_install PREFIX=%{_prefix}

%check
make test
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/vimb.metainfo.xml
 
%files
%{_bindir}/vimb
%dir %{_prefix}/lib/vimb
%{_prefix}/lib/vimb/webext_main.so
%{_datadir}/applications/vimb.desktop
%{_datadir}/metainfo/vimb.metainfo.xml
%{_mandir}/man1/vimb.1%{?ext_man}

%changelog
* Fri Jul  5 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Add pkgconfig(webkit2gtk-4.1) BuildRequires: fix build failed
- Add desktop-file-utils and appstream-glib BuildRequires: to
  validate files
- Remove unneeded BuildRequires:
  + pkgconfig(libsoup-gnome-2.4)
  + pkgconfig(libsoup-2.4)
  + pkgconfig(gtk+-3.0)
  + libwebkit2gtk-4_1-0
- enable make test
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.7.0:
  Added:
  * The new env variable $VIMB_SELECTION is set to the current selected text
    whenever a shellcmd is run #592.
  * Allow to push link url to queue by <S-LeftMouse> #610.
  * Allow to decide if html5 notfication are allowed #651. New setting
    notification=[ask,always,never] added.
  * Add new env VIMB_WIN_ID var for :shellcmd which holds the own window id.
  * Focus last focused input elemnt on page via i - or first found element if
    none was focused before.
  * Completion with bookmarked urls for :qpush and qunshift.
  * Setting scroll-multiplier to allow for faster scrolling by mouse wheel.
  * Setting intelligent-tracking-prevention to enable WebKit's Intelligent
    Tracking Prevention (ITP).
  * Setting javascript-enable-markup to disable js markup instead of disabling
  * Setting status-bar-show-settings to enable showing indicators to currently
    applied setting. Can be configured via config.h file.
    [#]define COOKIE GET_CHAR(c, "cookie-accept")
    [#]define STATUS_VARAIBLE_SHOW "%%c%%c%%c%%c%%c%%c%%c%%c", \
    CHAR_MAP(COOKIE, "always", 'A', CHAR_MAP(COOKIE, "origin", '@', 'a')), \
    GET_BOOL(c, "dark-mode") ? 'D' : 'd', \
    vb.incognito ? 'E' : 'e', \
    GET_BOOL(c, "images") ? 'I' : 'i', \
    GET_BOOL(c, "html5-local-storage") ? 'L' : 'l', \
    GET_BOOL(c, "stylesheet") ? 'M' : 'm', \
    GET_BOOL(c, "scripts") ? 'S' : 's', \
    GET_BOOL(c, "strict-ssl") ? 'T' : 't'
    JavaScript in general.
  * Allow to push link url to queue by Shift-LeftMouse.
  * New hint mode ;k do remove hinted elements like advertisement from DOM.
  * Allow to map <PageUp> and <Pagedown> keys.
  Changed:
  * Modes some files from $XDG_CONFIG_HOME/vimb into $XDG_DATA_HOME/vimb #582.
    Following files are affected bookmark, closed, command, config,
    cookies.db, history, queue and search.
    Existing files could be moved to the new location by
    mv $XDG_CONFIG_HOME/vimb/{bookmark,closed,command,cookies.db,history,queue,search} \
    $XDG_DATA_HOME/vimb
    [#] and same for existing profiles
    mkdir $XDG_DATA_HOME/vimb/<ProfileName>
    mv $XDG_CONFIG_HOME/vimb/<ProfileName>/{bookmark,closed,command,cookies.db,history,queue,search} \
    $XDG_DATA_HOME/vimb/<ProfileName>
  * Dependency moved to webkit-gtk 4.1 and libsoup 3.0
  Fixed:
  * Fixed ignored last line in config file if this line did not end in newline.
  * Fixed crash in normal_focus_last_active
  * Fixed hint keys going to webview if the hinted element had no src-attribut
  * Fixed erro in hinting on gitlab which caused the hints to have ho labels #659.
  * Prevent possible use after free in autocmd processing.
  Removed:
  * Expansion of %% to the current opened URI for :shellcmd was removed
    because it breaks the x-hint-command with URIs containing '%%'. But it is
    still possible to use $VIMB_URI for the :shellcmd which has the same
    effect.
* Thu Oct  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to pkgconfig style BuildRequires, ensure we pull in what
  the package really needs (fixes build in current Factory).
* Fri Jan  3 2020 Michael Vetter <mvetter@suse.com>
- Update to 3.6.0:
  Added:
  * :cleardata [listOfDataTypes] [timeSpan] command to clear various types of
    stored website data modified in the last timeSpan.
  * Setting hint-match-element to allow to disable the hinting to filter hints
    by the elements text content. This is useful if 'hint-keys' are set the
    chars instead of numbers.
  * New autocmd event LoadStarting to run auto commands before the first page
    content is loaded (Thanks to Patrick Steinhardt).
  * Setting geolocation with values ('ask', 'always' and 'never') to allow the
    user to permit or disable geolcation requests by default (Thanks to Alva).
  * Setting dark-mode to switch the webview into dark mode, which might be
    picked up by pages media query to setup dark styling (Thanks to Alva).
  * Option --cmd, -C to run ex commands on startup.
  Removed:
  * :clearcache was removed in favor of more advanced :cleardata command.
    The previous behaviour of :clearcache could be replaces by
    :cleardata memory-cache,disk-cache.
* Fri Aug 23 2019 mvetter@suse.com
- bsc#1146724: Set prefix during build
  So that it looks for webext_main.so at the right location
* Tue Jul 30 2019 mvetter@suse.com
- Update to 3.5.0:
  Added:
  * Add external download command #543 #348.
  * Added ephemeral mode by new option --incognito#562.
  Changed:
  * Hinting shows the current focused elements URI in the statusbar.
  * Show error if printing with :hardcopy fails #564.
  Fixed:
  * Fixed compilation if source is not in a git repo (Thanks to Patrick Steinhardt).
  * Fixed partial hidden hint labels on top of screen.
  * Fix segfault on open in new tabe from context menu #556.
  * Fix "... (null)" shown in title during url sanitization.
  Removed:
  * Setting private-browsing was removed in favor of --incognito option.
- Remove vim-3.4.0-fixbuild.patch: included upstream
* Wed Mar 27 2019 mvetter@suse.com
- Update to 3.4.0:
  Added:
  * Allow to show video in fullscreen, without statusbar and inputbox, if requested.
  * Added option --no-maximize to no start with maximized window #483.
  * New setting prevent-newwindow to enforce opening links into same window
    even if they are crafted by target="_blank" or using window.open(...)#544.
  Changed:
  * Increased min required webkit version to 2.20.x.
  * Use man page date instead of build date to make reproducible builds.
  * URLs shown on statusbar and title are now shown as punicode if they contain
    homographs.
  Fixed:
  * Fix out-of-bounds buffer access in parse_command (Thanks to Sören Tempel) #529.
  * Fixed none shown hint labels by Content-Security-Policy headers #531.
  * Fixed segfault on JavaScript window.close() call #537.
  * Fixed no char inserted in input mode after timeout and imap/inoremap
    candidate #546.
- Add vim-3.4.0-fixbuild.patch: fix non git build
* Wed Feb 13 2019 mvetter@suse.com
- Support parallel builds
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions.
* Tue Feb 12 2019 mvetter@suse.com
- Initial package vimb 3.3.0 for openSUSE
